@@ -19,7 +19,7 @@ WCF_ROOT = os.path.abspath(os.path.dirname(__file__))
 sys.path.insert(0, WCF_ROOT)
 import wcf_pb2  # noqa
 
-__version__ = "3.7.0.30.13"
+__version__ = "3.7.0.30.15"
 
 
 class Wcf():
@@ -70,7 +70,7 @@ class Wcf():
             cmd = f"{WCF_ROOT}/wcf.exe start {'debug' if debug else ''}"
             if os.system(cmd) != 0:
                 self.LOG.error("初始化失败！")
-                return
+                exit(-1)
 
         # 连接 RPC
         self.cmd_socket = pynng.Pair1()  # Client --> Server，发送消息
@@ -227,6 +227,18 @@ class Wcf():
         rsp = self._send_request(req)
         return rsp.status
 
+    def send_xml(self, receiver: str, xml: str, type: int, path: str = None) -> int:
+        """发送文件"""
+        req = wcf_pb2.Request()
+        req.func = wcf_pb2.FUNC_SEND_XML  # FUNC_SEND_XML
+        req.xml.receiver = receiver
+        req.xml.content = xml
+        req.xml.type = type
+        if path:
+            req.xml.path = path
+        rsp = self._send_request(req)
+        return rsp.status
+
     def get_msg(self, block=True) -> WxMsg:
         return self.msgQ.get(block, timeout=1)
 
@@ -331,7 +343,7 @@ class Wcf():
         return result
 
     def accept_new_friend(self, v3: str, v4: str) -> int:
-        """发送文件"""
+        """添加好友"""
         req = wcf_pb2.Request()
         req.func = wcf_pb2.FUNC_ACCEPT_FRIEND  # FUNC_ACCEPT_FRIEND
         req.v.v3 = v3
@@ -351,10 +363,19 @@ class Wcf():
         friends = []
         for cnt in self.get_contacts():
             if (cnt.wxid.endswith("@chatroom")      # 群聊
-                    or cnt.wxid.startswith("gh_")       # 公众号
-                    or cnt.wxid in not_friends.keys()   # 其他杂号
+                or cnt.wxid.startswith("gh_")       # 公众号
+                or cnt.wxid in not_friends.keys()   # 其他杂号
                 ):
                 continue
             friends.append(cnt)
 
         return friends
+
+    def add_chatroom_members(self, roomid: str, wxids: str) -> int:
+        """添加群成员"""
+        req = wcf_pb2.Request()
+        req.func = wcf_pb2.FUNC_ADD_ROOM_MEMBERS  # FUNC_ADD_ROOM_MEMBERS
+        req.m.roomid = roomid
+        req.m.wxids = wxids
+        rsp = self._send_request(req)
+        return rsp.status
